<?php 
$translations = array(
	'General_Locale' => 'nl_NL.UTF-8',
	'General_TranslatorName' => 'Martijn van Laar, Hannes Bossuyt',
	'General_TranslatorEmail' => 'martijn@mvanlaar.net, hannes@randomize.be',
	'General_EnglishLanguageName' => 'Dutch',
	'General_OriginalLanguageName' => 'Nederlands',
	'General_Unknown' => 'Onbekend',
	'General_Required' => 'verplicht',
	'General_Error' => 'fout',
	'General_Warning' => 'let op',
	'General_BackToHomepage' => 'Terug naar de Piwik homepage',
	'General_Yes' => 'Ja',
	'General_No' => 'Nee',
	'General_Delete' => 'Verwijderen',
	'General_Edit' => 'Aanpassen',
	'General_Ok' => 'Ok',
	'General_Close' => 'Sluiten',
	'General_Logout' => 'Uitloggen',
	'General_Done' => 'Klaar',
	'General_LoadingData' => 'Data laden...',
	'General_ErrorRequest' => 'Oeps&hellip; er was een probleem tijdens het opvragen van de date. probeer het nogmaals',
	'General_Next' => 'Volgende',
	'General_Previous' => 'Vorige',
	'General_Table' => 'Tabel',
	'General_Piechart' => 'Taart diagram',
	'General_TagCloud' => 'Tag wolk',
	'General_VBarGraph' => 'Verticaal staaf diagram',
	'General_Refresh' => 'Ververs de pagina',
	'General_ColumnNbUniqVisitors' => 'Unieke bezoekers',
	'General_ColumnNbVisits' => 'Bezoeken',
	'General_ColumnLabel' => 'Waarde',
	'General_Save' => 'Bewaar',
	'General_Search' => 'Zoek',
	'General_Others' => 'Andere',
	'General_Export' => 'Exporteren',
	'General_Visitors' => 'Bezoekers',
	'General_NoDataForGraph' => 'Geen data gevonden voor deze grafiek',
	'General_NoDataForTagCloud' => 'Geen data gevonden voor deze label wolk',
	'General_PiwikIsACollaborativeProject' => '%s Piwik %s is een project in samenwerkings verband en bevindt zich in de beta fase. Neem %scontact%s met ons op wanneer u wilt helpen!',
	'General_Website' => 'Website',
	'General_HelloUser' => 'Hallo, %s!',
	'General_OpenSourceWebAnalytics' => 'Open Source Web Analytics',
	'General_YourDashboard' => 'Jouw Dashbord',
	'General_API' => 'API',
	'General_Widgets' => 'Widgets',
	'General_Settings' => 'Instellingen',
	'General_GiveUsYourFeedback' => 'Geef ons commentaar',
	'General_ColumnActionsPerVisit' => 'Acties per bezoek',
	'General_ColumnAvgTimeOnSite' => 'Gem. tijd op de site',
	'General_ColumnBounceRate' => 'Bounce Rate',
	'General_ColumnPageviews' => 'Pageviews',
	'General_ColumnUniquePageviews' => 'Unieke Pageviews',
	'General_DisplayNormalTable' => 'Geef een normale tabel weer',
	'General_DisplayMoreData' => 'Geef meer data weer',
	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'Je kijkt op dit moment naar een demo van %s; %sdownload%s de volledige versie! Kijk naar %s',
	'General_Loading' => 'Laden...',
	'General_ExportAsImage' => 'Exporteer als afbeelding',
	'General_SaveImageOnYourComputer' => 'Om de afbeelding op te slaan op uw computer, klik rechts op de afbeelding en selecteer "Sla afbeelding op als..."',
	'General_ColumnNbActions' => 'Acties',
	'General_ColumnMaxActions' => 'Maximaal aantal acties per bezoek.',
	'General_ColumnSumVisitLength' => 'Totale tijd gespendeerd door de bezoekers (in seconden)',
	'General_ColumnValuePerVisit' => 'Waarde per bezoek',
	'General_ColumnVisitsWithConversions' => 'Bezoekers met conversies',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s is een samenwerkings project. %s Als je Piwik handig vindt, dan kun je helpen! Zoek uit %s Hoe je kan meehelpen aan Piwik.%s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s is beschikbaar. %s Gelieve nu te updaten! %s \'zie %s wijzigingen%s)',
	'General_BackToPiwik' => 'Terug naar Piwik',
	'General_ShortMonth_1' => 'Jan',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mrt',
	'General_ShortMonth_4' => 'Apr',
	'General_ShortMonth_5' => 'Mei',
	'General_ShortMonth_6' => 'Jun',
	'General_ShortMonth_7' => 'Jul',
	'General_ShortMonth_8' => 'Aug',
	'General_ShortMonth_9' => 'Sep',
	'General_ShortMonth_10' => 'Okt',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Dec',
	'General_LongMonth_1' => 'Januari',
	'General_LongMonth_2' => 'Februari',
	'General_LongMonth_3' => 'Maart',
	'General_LongMonth_4' => 'April',
	'General_LongMonth_5' => 'Mei',
	'General_LongMonth_6' => 'Juni',
	'General_LongMonth_7' => 'Juli',
	'General_LongMonth_8' => 'Augustus',
	'General_LongMonth_9' => 'September',
	'General_LongMonth_10' => 'Oktober',
	'General_LongMonth_11' => 'November',
	'General_LongMonth_12' => 'December',
	'General_ShortDay_1' => 'Ma',
	'General_ShortDay_2' => 'Di',
	'General_ShortDay_3' => 'Wo',
	'General_ShortDay_4' => 'Do',
	'General_ShortDay_5' => 'Vr',
	'General_ShortDay_6' => 'Za',
	'General_ShortDay_7' => 'Zo',
	'General_LongDay_1' => 'Maandag',
	'General_LongDay_2' => 'Dinsdag',
	'General_LongDay_3' => 'Woensdag',
	'General_LongDay_4' => 'Donderdag',
	'General_LongDay_5' => 'Vrijdag',
	'General_LongDay_6' => 'Zaterdag',
	'General_LongDay_7' => 'Zondag',
	'Actions_Actions' => 'Acties',
	'Actions_SubmenuPages' => 'Pagina\'s',
	'Actions_SubmenuOutlinks' => 'Externe links',
	'Actions_SubmenuDownloads' => 'Downloads',
	'API_QuickDocumentation' => '<h2>API beknopte documentatie</h2><p>Wanneer u geen data voor vandaag heeft, kunt u eerst <a href=\'misc/generateVisits.php\' target=_blank>wat data genereren</a> door middel van het Bezoek Generator script.</p><p>U kunt voor elke methode een ander formaat proberen. Het is heel eenvoudig data uit piwik te halen!</p><p><b>Voor meer informatie bekijk de <a href=\'http://dev.piwik.org/trac/wiki/API\'>officiele API Documentatie</a> of de <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API Reference</a>.</b></P><h2>Gebruiker herkenning</h2><p>Wanneer u <b>de data van uw scripts opvraagt middels een crontab, etc. </b> u dient de volgende parameter <code><u>&token_auth=%s</u></code> toe te voegen aan de API oproep URLs die identificatie vereisen.</p><p>Deze token_auth is zo persoonlijk als uw login en password, <b>deel deze informatie niet met anderen!</p>',
	'API_LoadedAPIs' => 'Succesvol %s APIs geladen',
	'CoreHome_NoPrivileges' => 'U bent ingelogd als \'%s\' maar het lijkt er op dat u niet voldoende rechten bezit Piwik te gebruiken.<br />Vraag uw Piwik administrator om \'kijkers rechten\' voor een website.',
	'CoreHome_JavascriptDisabled' => 'JavaScript moet geactiveerd zijn om Piwik in de standaard modus te gebruiken.<br />Het lijkt er op dat JavaScript of uitgeschakeld is of niet ondersteund wordt door uw browser.<br />Om de standaard modus te gebruiken, activeer JavaScript in uw browser instellingen, probeer het daarna %1snogmaals%2s.<br />',
	'CoreHome_TableNoData' => 'Geen data voor deze tabel gevonden.',
	'CoreHome_CategoryNoData' => 'Geen data in deze catagorie. Probeer "Toon alle data".',
	'CoreHome_ShowJSCode' => 'toon de javascript code',
	'CoreHome_IncludeAllPopulation_js' => 'Toon alle data',
	'CoreHome_ExcludeLowPopulation_js' => 'Verberg marginale data',
	'CoreHome_PageOf_js' => '%s van %s',
	'CoreHome_Loading_js' => 'Laden...',
	'CoreHome_LocalizedDateFormat' => '%A %d %B %Y',
	'CoreHome_PeriodDay' => 'Dag',
	'CoreHome_PeriodWeek' => 'Week',
	'CoreHome_PeriodMonth' => 'Maand',
	'CoreHome_PeriodYear' => 'Jaar',
	'CoreHome_DaySu_js' => 'Zo',
	'CoreHome_DayMo_js' => 'Ma',
	'CoreHome_DayTu_js' => 'Di',
	'CoreHome_DayWe_js' => 'Wo',
	'CoreHome_DayTh_js' => 'Do',
	'CoreHome_DayFr_js' => 'Vry',
	'CoreHome_DaySa_js' => 'Za',
	'CoreHome_MonthJanuary_js' => 'januari',
	'CoreHome_MonthFebruary_js' => 'februari',
	'CoreHome_MonthMarch_js' => 'maart',
	'CoreHome_MonthApril_js' => 'april',
	'CoreHome_MonthMay_js' => 'mei',
	'CoreHome_MonthJune_js' => 'juni',
	'CoreHome_MonthJuly_js' => 'july',
	'CoreHome_MonthAugust_js' => 'augustus',
	'CoreHome_MonthSeptember_js' => 'september',
	'CoreHome_MonthOctober_js' => 'oktober',
	'CoreHome_MonthNovember_js' => 'november',
	'CoreHome_MonthDecember_js' => 'december',
	'CorePluginsAdmin_Plugins' => 'Plugins',
	'CorePluginsAdmin_PluginsManagement' => 'Plugin manager',
	'CorePluginsAdmin_MainDescription' => 'Met plugins breidt u de functionaliteit van piwik uit. Wanneer een plugin ge&iuml;nstalleerd is, kan deze hier aan- en uitgeschakeld worden.',
	'CorePluginsAdmin_Plugin' => 'Plugin',
	'CorePluginsAdmin_Version' => 'Versie',
	'CorePluginsAdmin_Description' => 'Omschrijving',
	'CorePluginsAdmin_Status' => 'Status',
	'CorePluginsAdmin_Action' => 'Actie',
	'CorePluginsAdmin_PluginHomepage' => 'Plugins',
	'CorePluginsAdmin_Activated' => 'Ingeschakeld',
	'CorePluginsAdmin_Active' => 'Ingeschakeld',
	'CorePluginsAdmin_Inactive' => 'Uitgeschakeld',
	'CorePluginsAdmin_ActivatedHelp' => 'Deze plugin kan niet uitgeschakeld worden',
	'CorePluginsAdmin_Deactivate' => 'Uitschakelen',
	'CorePluginsAdmin_Activate' => 'Inschakelen',
	'CorePluginsAdmin_MenuPlugins' => 'Plugins',
	'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; Update',
	'CoreUpdater_UpdateRequired' => 'Upgrade vereist',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Uw Piwik database is niet up to date en zal ge-upgrade moeten worden om verder te kunnen gaan.',
	'CoreUpdater_PiwikWillBeUpgradedToVersionX' => 'Piwik zal ge-upgrade worden naar versie %s. ',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'De volgende plugins zullen ge-upgrade worden: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'De upgrade kan enige tijd in beslag nemen, graag uw geduld.',
	'CoreUpdater_UpgradePiwik' => 'Upgrade Piwik',
	'CoreUpdater_HelpMessageContent' => 'Controleer de %s Piwik FAQ %s waarin de meest voorkomende upgrade foutmeldingen worden uitgelegd. %s Vraag uw systeem beheerder - deze kan u wellicht helpen met deze fout die waarschijnlijk gerelateerd is aan de configuratie van uw web- of mysql server.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritieke fout tijdens upgrade:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Hierboven staat de foutmelding. Hierin zou de oorzaak naar voren moeten komen, mocht u desondanks nog vragen hebben: ',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'The upgrade is voltooid, maar met fouten tijdens het process. Lees de omschrijvingen hierboven voor meer informatie. Voor verdere hulp:',
	'CoreUpdater_UpgradeComplete' => 'Upgrade voltooid!',
	'CoreUpdater_WarningMessages' => 'Waarschuwings bericht:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Fout tijdens het updaten van de plugins:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'We hebben de volgende plugins ge-deactiveerd',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik upgrade was succesvol!',
	'CoreUpdater_ContinueToPiwik' => 'Ga verder naar Piwik',
	'Dashboard_Dashboard' => 'Dashboard',
	'Dashboard_AddWidget' => 'Voeg een widget toe...',
	'Dashboard_DeleteWidgetConfirm' => 'Weet u zeker dat u deze widget van het dashboard wilt verwijderen?',
	'Dashboard_SelectWidget' => 'Selecteer een widget om toe te voegen aan het dashboard',
	'Dashboard_AddPreviewedWidget' => 'Voeg de getoonde widget toe aan het dashboard',
	'Dashboard_WidgetPreview' => 'Widget voorvertoning',
	'Dashboard_TitleWidgetInDashboard_js' => 'Deze widget zit reeds in het dashboard',
	'Dashboard_TitleClickToAdd_js' => 'Klik om aan het dashboard toe te voegen',
	'Dashboard_LoadingPreview_js' => 'Bezig voorvertoning te laden, even geduld a.u.b...',
	'Dashboard_LoadingWidget_js' => 'Bezig widget te laden, even geduld a.u.b...',
	'Dashboard_WidgetNotFound_js' => 'Widget niet gevonden',
	'DBStats_DatabaseUsage' => 'Database gebruik',
	'DBStats_MainDescription' => 'Piwik slaat alle analyse data op in een MySQL database. Momenteel is de omvang van deze database %s.',
	'DBStats_Table' => 'Tabel',
	'DBStats_RowNumber' => 'Rij nummer',
	'DBStats_DataSize' => 'Data omvang',
	'DBStats_IndexSize' => 'Index grootte',
	'DBStats_TotalSize' => 'Totale grootte',
	'Installation_Installation' => 'Installatie',
	'Installation_InstallationStatus' => 'Installatie status',
	'Installation_PercentDone' => '%s %% Gereed',
	'Installation_NoConfigFound' => 'Het Piwik configuratie bestand werd niet gevonden.<br /><b>&nbsp;&nbsp;&raquo; U kunt <a href=\'index.php\'>Piwik nu installeren</a></b><br /><small>Wanneer u Piwik al eerder ge&iuml;nstalleerd heeft, en er zit reeds data in de Piwik tabellen: maakt u zich geen zorgen, u kunt uw bestaande data blijven gebruiken!</small>\',',
	'Installation_MysqlSetup' => 'Mysql database instellingen',
	'Installation_MysqlErrorConnect' => 'Fout tijdens het verbinden met de Mysql database',
	'Installation_JsTag' => 'Javascript tag',
	'Installation_JsTagHelp' => '<p>Om alle bezoekers te tellen, moet u de javascript code op elke pagina toevoegen.</p><p>Uw pagina\'s hoeven niet per se in php geschreven zijn, het werkt met vele soorten pagina\'s (of het nou in HTML, ASP, Perl of een andere taal is).</p><p>Hier is de code die u dient toe te voegen: (knip en plak in al uw pagina\'s) </p>',
	'Installation_Congratulations' => 'Gefeliciteerd',
	'Installation_ContratulationsHelp' => '<p>Gefeliciteerd! Uw Piwik installatie is compleet.</p><p>Voeg het javascript toe aan uw pagina\'s, en wacht op uw eerste bezoekers!</p>',
	'Installation_GoToPiwik' => 'Naar Piwik',
	'Installation_SetupWebsite' => 'Configureer een website',
	'Installation_SetupWebsiteError' => 'Er heeft zich een fout voorgedaan tijdens het toevoegen van de website',
	'Installation_GeneralSetup' => 'Algemene instellingen',
	'Installation_GeneralSetupSuccess' => 'Algemene instellingen met succes toegepast',
	'Installation_SystemCheck' => 'Systeem controle',
	'Installation_SystemCheckPhp' => 'PHP versie',
	'Installation_SystemCheckPdo' => 'Pdo extensie',
	'Installation_SystemCheckPdoMysql' => 'Pdo_Mysql extensie',
	'Installation_SystemCheckPdoError' => 'U dient de <code>php_pdo</code> en de <code>php_pdo_mysql</code> extensies in uw php.ini file te activeren.',
	'Installation_SystemCheckPdoHelp' => 'Op een windows server kunt u de volgende regels toevoegen aan uw php.ini %s <br /><br />Op een linux server kunt u php compileren met de volgende opties %s In uw php.ini, voeg de volgende regels toe %s<br /><br />Meer informatie op de <a style="color:red" href="http://php.net/pdo">PHP website</a>.',
	'Installation_SystemCheckWriteDirs' => 'Mappen met schrijf-rechten',
	'Installation_SystemCheckWriteDirsHelp' => 'Om dit probleem te verhelpen op uw linux server, type de volgende commando(s)',
	'Installation_SystemCheckMemoryLimit' => 'Geheugen limiet',
	'Installation_SystemCheckMemoryLimitHelp' => 'Het meten van een website met veel bezoekers kan meer geheugen vereisen dan momenteel is toegestaan.<br />Controleer de directive memory_limit in uw php.ini file indien noodzakelijk.',
	'Installation_SystemCheckGD' => 'GD &gt; 2.x (graphics)',
	'Installation_SystemCheckGDHelp' => 'De sparklines (kleine grafieken) zullen niet werken.',
	'Installation_SystemCheckTimeLimit' => 'set_time_limit() toegestaan',
	'Installation_SystemCheckTimeLimitHelp' => 'Het meten van een website met veel bezoekers kan meer tijd in beslag nemen dan momenteel is toegestaan.<br />Controleer de directive max_execution_time  in uw php.ini file indien noodzakelijk',
	'Installation_SystemCheckMail' => 'mail() toegestaan',
	'Installation_SystemCheckError' => 'Er is een fout opgetreden - deze dient verholpen te zijn alvorens u verder gaat',
	'Installation_SystemCheckWarning' => 'Piwik zal normaal functioneren, maar er zullen een aantal mogelijkheden ontbreken',
	'Installation_Tables' => 'Tabellen cre&uuml;ren',
	'Installation_TablesWarning' => 'Sommige <span id="linkToggle">Piwik tabellen</span> bestaan reeds in de database',
	'Installation_TablesFound' => 'De volgende tabellen werden aangetroffen in de database',
	'Installation_TablesWarningHelp' => 'Kies voor het hergebruiken van deze tabellen of voor een schone installatie van de database.',
	'Installation_TablesReuse' => 'Hergebruik de bestaande tabellen',
	'Installation_TablesDelete' => 'Verwijder de gevonden tabellen',
	'Installation_TablesDeletedSuccess' => 'Bestaande Piwik tabellen met succes verwijderd',
	'Installation_TablesCreatedSuccess' => 'De tabellen zijn succesvol aangemaakt',
	'Installation_TablesDeleteConfirm' => 'Weet u zeker dat u alle piwik tabellen van deze database wilt verwijderen?',
	'Installation_Welcome' => 'Welkom!',
	'Installation_WelcomeHelp' => '<p>Piwik is een open source web analytics software pakket die u op simpele wijze de gegevens van uw bezoekers presenteert.</p><p>Dit proces is opgedeeld in %s simpele stappen welke ongeveer 5 minuten in beslag nemen.</p>',
	'Installation_CongratulationsHelp' => '<p>Gefeliciteerd! Uw Piwik installatie is voltooid.</p><p>Controleer of de javascript code geplaatst is op uw paginas, en wacht op de eerste bezoekers!</p>',
	'Installation_DatabaseCreatedSuccess' => 'Database %s successvol aangemaakt',
	'Login_LoginPasswordNotCorrect' => 'Login & Password niet correct',
	'Login_Login' => 'Login',
	'Login_Password' => 'Password',
	'Login_LoginOrEmail' => 'Login of E-mail',
	'Login_LogIn' => 'Log in',
	'Login_Logout' => 'Uitloggen',
	'Login_LostYourPassword' => 'Password vergeten?',
	'Login_RemindPassword' => 'Password reminder',
	'Login_PasswordReminder' => 'Vul uw gebruikersnaam of e-mail adres in. U zal middels een e-mail een nieuw password ontvangen.',
	'Login_InvalidUsernameEmail' => 'Ongeldige gebruikersnaam en/of e-mail adres',
	'Login_MailTopicPasswordRecovery' => 'Uw password',
	'Login_MailPasswordRecoveryBody' => 'Hallo %1s,\n\nUw nieuwe password is: %2s\n\nU kunt nu inloggen op: %3s',
	'Login_PasswordSent' => 'Uw password is verzonden. Controleer uw e-mail.',
	'Login_ContactAdmin' => 'Mogelijke reden: uw host heeft mogelijk de mail() functie geblokkeerd. <br />Neem contact op met uw Piwik administrator.',
	'Provider_WidgetProviders' => 'Providers',
	'Provider_SubmenuLocationsProvider' => 'Lokatie & provider',
	'Referers_Referers' => 'Referenties',
	'Referers_SearchEngines' => 'Zoek machines',
	'Referers_Keywords' => 'Zoek termen',
	'Referers_DirectEntry' => 'Direct bezoek',
	'Referers_Websites' => 'Websites',
	'Referers_Newsletters' => 'Nieuwsbrieven',
	'Referers_Campaigns' => 'Campagnes',
	'Referers_Evolution' => 'Meest recente ontwikkelingen',
	'Referers_Type' => 'Bezoekers per afkomst',
	'Referers_TypeDirectEntries' => '%s directe bezoekers',
	'Referers_TypeSearchEngines' => '%s bezoekers via zoek machines',
	'Referers_TypeWebsites' => '%s bezoekers via websites',
	'Referers_TypeNewsletters' => '%s bezoekers via nieuwsbrieven',
	'Referers_TypeCampaigns' => '%s bezoekers via campagnes',
	'Referers_Other' => 'Unieke referenties',
	'Referers_OtherDistinctSearchEngines' => '%s zoek machines',
	'Referers_OtherDistinctKeywords' => '%s zoek termen',
	'Referers_OtherDistinctWebsites' => '%1s websites (%2s urls)',
	'Referers_OtherDistinctCampaigns' => '%s campagnes',
	'Referers_TagCloud' => 'Label wolk',
	'Referers_SubmenuEvolution' => 'Totalen',
	'Referers_SubmenuSearchEngines' => 'Zoekmachines & termen',
	'Referers_SubmenuWebsites' => 'Websites',
	'Referers_SubmenuCampaigns' => 'Campagnes',
	'Referers_WidgetKeywords' => 'Top zoektermen',
	'Referers_WidgetCampaigns' => 'Top campagnes',
	'Referers_WidgetExternalWebsites' => 'Top websites',
	'Referers_WidgetSearchEngines' => 'Top zoekmachines',
	'Referers_WidgetOverview' => 'Overzicht',
	'SitesManager_Sites' => 'Websites',
	'SitesManager_WebsitesManagement' => 'Website manager',
	'SitesManager_MainDescription' => 'Voeg toe, actualiseer en verwijder. Ook het javascript voor op uw website is hier te vinden.',
	'SitesManager_JsCode' => 'Javascript code',
	'SitesManager_JsCodeHelp' => 'Voeg dit javascript toe aan de pagina\'s van de te meten website',
	'SitesManager_ShowJsCode' => 'toon code',
	'SitesManager_NoWebsites' => 'U heeft geen websites in beheer.',
	'SitesManager_AddSite' => 'Voeg een nieuwe website toe',
	'SitesManager_Id' => 'Id',
	'SitesManager_Name' => 'Naam',
	'SitesManager_Urls' => 'URLs',
	'SitesManager_MenuSites' => 'Websites',
	'SitesManager_DeleteConfirm_js' => 'Weet u zeker dat u de volgende website wil verwijderen: %s?',
	'SitesManager_ExceptionDeleteSite' => 'Het is niet mogelijk deze website te verwijderen aangezien het de enige geregistreerde website is. Voeg eerst een nieuwe website toe alvorens deze te verwijderen.',
	'SitesManager_ExceptionNoUrl' => 'U moet minimaal &eacute;&eacute;n url bepalen voor deze website.',
	'SitesManager_ExceptionEmptyName' => 'De website dient een naam te hebben.',
	'SitesManager_ExceptionInvalidUrl' => 'deze url \'%s\' is niet geldig.',
	'TranslationsAdmin_MenuTranslations' => 'Vertalingen',
	'TranslationsAdmin_MenuLanguages' => 'Talen',
	'TranslationsAdmin_Plugin' => 'Plugin',
	'TranslationsAdmin_Definition' => 'Definitie',
	'TranslationsAdmin_DefaultString' => 'Standaard waarde (engels)',
	'TranslationsAdmin_TranslationString' => 'Vertaalde waarde (huidige taal: %s)',
	'TranslationsAdmin_Translations' => 'Vertalingen',
	'TranslationsAdmin_FixPermissions' => 'Repareer bestands-permissies',
	'TranslationsAdmin_AvailableLanguages' => 'Beschikbare talen',
	'TranslationsAdmin_AddLanguage' => 'Voeg een taal toe',
	'TranslationsAdmin_LanguageCode' => 'Taal code',
	'TranslationsAdmin_Export' => 'Exporteer taal',
	'TranslationsAdmin_Import' => 'Importeer taal',
	'UserCountry_Country' => 'Land',
	'UserCountry_Continent' => 'Continent',
	'UserCountry_DistinctCountries' => '%s unieke landen',
	'UserCountry_SubmenuLocations' => 'Locaties',
	'UserCountry_WidgetContinents' => 'Bezoeker continenten',
	'UserCountry_WidgetCountries' => 'Bezoeker landen',
	'UserCountry_country_ac' => 'Ascension eilanden',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'Verenigde Emiraten',
	'UserCountry_country_af' => 'Afghanistan',
	'UserCountry_country_ag' => 'Antigua en Brabuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albani&euml;',
	'UserCountry_country_am' => 'Armeni&euml;',
	'UserCountry_country_an' => 'Nederlandse Antillen',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antartica',
	'UserCountry_country_ar' => 'Argentini&euml;',
	'UserCountry_country_as' => 'Samoa',
	'UserCountry_country_at' => 'Oostenrijk',
	'UserCountry_country_au' => 'Australi&euml;',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_az' => 'Azerbeijan',
	'UserCountry_country_ba' => 'Bosni&euml; en Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgi&euml;',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgari&euml;',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivi&euml;',
	'UserCountry_country_br' => 'Barzili&euml;',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bv' => 'Bouvet eiland',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Belarus',
	'UserCountry_country_bz' => 'Blize',
	'UserCountry_country_ca' => 'Canada',
	'UserCountry_country_cc' => 'Cocos eilanden',
	'UserCountry_country_cd' => 'Congo',
	'UserCountry_country_cf' => 'Centraal Afrika',
	'UserCountry_country_cg' => 'Congo',
	'UserCountry_country_ch' => 'Zwitserland',
	'UserCountry_country_ci' => 'Ivoorkust',
	'UserCountry_country_ck' => 'Cook eilanden',
	'UserCountry_country_cl' => 'Chili',
	'UserCountry_country_cm' => 'Kameroen',
	'UserCountry_country_cn' => 'China',
	'UserCountry_country_co' => 'Colombia',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Kaap de goed hoop',
	'UserCountry_country_cx' => 'Paaseilanden',
	'UserCountry_country_cy' => 'Cyprus',
	'UserCountry_country_cz' => 'Tsjechi&euml;',
	'UserCountry_country_de' => 'Duitsland',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Denemarken',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'Dominicaanse republiek',
	'UserCountry_country_dz' => 'Algerij&euml;',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Egypte',
	'UserCountry_country_eh' => 'West Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Spanje',
	'UserCountry_country_et' => 'Ethiopi&euml;',
	'UserCountry_country_fi' => 'Finland',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falkland Eilanden',
	'UserCountry_country_fm' => 'Micronesia',
	'UserCountry_country_fo' => 'Farao Eilanden',
	'UserCountry_country_fr' => 'Frankrijk',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Georgi&euml;',
	'UserCountry_country_gf' => 'Frans Guinea',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Groenland',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Equatoriaal Guinea',
	'UserCountry_country_gr' => 'Griekenland',
	'UserCountry_country_gs' => 'Zuid Georgi&euml; ',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard eiland en McDonald eilanden',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Kroati&euml;',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Hongarij&euml;',
	'UserCountry_country_id' => 'Indonesi&euml;',
	'UserCountry_country_ie' => 'Ierland',
	'UserCountry_country_il' => 'Isra&euml;l',
	'UserCountry_country_im' => 'Man eiland',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'Brits Indisch territoriale wateren',
	'UserCountry_country_iq' => 'Irak',
	'UserCountry_country_ir' => 'Iran',
	'UserCountry_country_is' => 'IJsland',
	'UserCountry_country_it' => 'Itali&euml;',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Jordaan',
	'UserCountry_country_jp' => 'Japan',
	'UserCountry_country_ke' => 'Kenia',
	'UserCountry_country_kg' => 'Kyrgyzstan',
	'UserCountry_country_kh' => 'Cambodja',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comoros',
	'UserCountry_country_kn' => 'Sint Kitts en Nevis',
	'UserCountry_country_kp' => 'Noord Korea',
	'UserCountry_country_kr' => 'Zuid Korea',
	'UserCountry_country_kw' => 'Koeweit',
	'UserCountry_country_ky' => 'Kaaiman eilanden',
	'UserCountry_country_kz' => 'Kazachstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Libanon',
	'UserCountry_country_lc' => 'Sint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Libi&euml;',
	'UserCountry_country_ls' => 'Lesbos',
	'UserCountry_country_lt' => 'Litouwen',
	'UserCountry_country_lu' => 'Luxemburg',
	'UserCountry_country_lv' => 'Letland',
	'UserCountry_country_ly' => 'Libi&euml;',
	'UserCountry_country_ma' => 'Marokko',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Moldavi&euml;',
	'UserCountry_country_mg' => 'Madagaskar',
	'UserCountry_country_mh' => 'Marshall eilanden',
	'UserCountry_country_mk' => 'Macedoni&euml;',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongoli&euml;',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Noordelijk Marina eilanden',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauristius',
	'UserCountry_country_mv' => 'Malledieven',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexico',
	'UserCountry_country_my' => 'Maleisi&euml;',
	'UserCountry_country_mz' => 'Mozambique',
	'UserCountry_country_na' => 'Namibi&euml;',
	'UserCountry_country_nc' => 'Nieuw Caledonia',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk eiland',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Nederland',
	'UserCountry_country_no' => 'Noorwegen',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'Nieuw Zeeland',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'Frans Polynesi&euml;',
	'UserCountry_country_pg' => 'Papua Nieuw Guinea',
	'UserCountry_country_ph' => 'Filipijnen',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Polen',
	'UserCountry_country_pm' => 'Sint Petersburg',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestijnen',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Reunie eiland',
	'UserCountry_country_ro' => 'Roemeni&euml;',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudi Arabi&euml;',
	'UserCountry_country_sb' => 'Solomon Eilanden',
	'UserCountry_country_sc' => 'Seychelles',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Zweden',
	'UserCountry_country_sg' => 'Singapore',
	'UserCountry_country_sh' => 'Sint Helena',
	'UserCountry_country_si' => 'Sloveni&euml;',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovaki&euml;',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somali&euml;',
	'UserCountry_country_sr' => 'Suriname',
	'UserCountry_country_st' => 'Sao Tome en Principe',
	'UserCountry_country_su' => 'Voormalig rusland',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Syrische republiek',
	'UserCountry_country_sz' => 'Swaziland',
	'UserCountry_country_tc' => 'Turkse en Caicos Eilanden',
	'UserCountry_country_td' => 'Chad',
	'UserCountry_country_tf' => 'Franse territorialen',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thailand',
	'UserCountry_country_tj' => 'Tsjikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisi&euml;',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Oost Timor',
	'UserCountry_country_tr' => 'Turkije',
	'UserCountry_country_tt' => 'Trinidad en Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzani&euml;',
	'UserCountry_country_ua' => 'Ukraine',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Verenigd Koningkrijk',
	'UserCountry_country_gb' => 'Groot britanni&euml;',
	'UserCountry_country_um' => 'Eilanden van de Verenigde Staten',
	'UserCountry_country_us' => 'Verenigde Staten',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vaticaanstad',
	'UserCountry_country_vc' => 'Sint Vincent en de Grenadinen',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Britse Maagden eilanden',
	'UserCountry_country_vi' => 'Maagden eilanden',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis en Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Jemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Joegoslavi&euml;',
	'UserCountry_country_za' => 'Zuid Afrika',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Europa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_asi' => 'Asi&euml;',
	'UserCountry_continent_ams' => 'Zuid- en Centraal Amerika',
	'UserCountry_continent_amn' => 'Noord Amerika',
	'UserCountry_continent_oce' => 'Oceanie',
	'UserCountry_country_ru' => 'Rusland',
	'UserCountry_country_rs' => 'Siberi&euml;',
	'UserSettings_BrowserFamilies' => 'Browser per type',
	'UserSettings_Browsers' => 'Browser per versie',
	'UserSettings_Plugins' => 'Ge&iuml;nstalleerde plugins',
	'UserSettings_Configurations' => 'Configuraties',
	'UserSettings_OperatingSystems' => 'Besturings systemen',
	'UserSettings_Resolutions' => 'Scherm resoluties',
	'UserSettings_WideScreen' => 'Scherm configuratie',
	'UserSettings_WidgetResolutions' => 'Scherm resoluties',
	'UserSettings_WidgetBrowsers' => 'Browser per versie',
	'UserSettings_WidgetPlugins' => 'Ge&iuml;nstalleerde plugins',
	'UserSettings_WidgetWidescreen' => 'Scherm configuratie',
	'UserSettings_WidgetBrowserFamilies' => 'Browser per type',
	'UserSettings_WidgetOperatingSystems' => 'Besturings systemen',
	'UserSettings_WidgetGlobalVisitors' => 'Configuraties',
	'UserSettings_SubmenuSettings' => 'Instellingen',
	'UsersManager_UsersManagement' => 'Gebruiker manager',
	'UsersManager_UsersManagementMainDescription' => 'Cre&euml;er nieuwe, of actualiseer bestaande gebruikers',
	'UsersManager_ManageAccess' => 'Toegangs-beheer',
	'UsersManager_MainDescription' => 'Stel in welke gebruikers toegang hebben tot de Piwik rapporten van deze website. U kan de toegangs rechten voor alle websites tegelijk bepalen door deze optie te kiezen in de dropdown',
	'UsersManager_Sites' => 'Websites',
	'UsersManager_AllWebsites' => 'Alle websites',
	'UsersManager_ApplyToAllWebsites' => 'Pas toe op elke website',
	'UsersManager_User' => 'Gebruiker',
	'UsersManager_PrivNone' => 'Geen toegang',
	'UsersManager_PrivView' => 'Kijken',
	'UsersManager_PrivAdmin' => 'Admin',
	'UsersManager_ChangeAllConfirm' => 'Weet u zeker dat u de rechten van \'%s\' voor alle websites wilt wijzigen?',
	'UsersManager_Login' => 'Inloggen',
	'UsersManager_Password' => 'Password',
	'UsersManager_Email' => 'Email',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_Token' => 'token_auth',
	'UsersManager_Edit' => 'Bewerk',
	'UsersManager_AddUser' => 'Voeg gebruiker toe',
	'UsersManager_MenuUsers' => 'Gebruikers',
	'UsersManager_DeleteConfirm_js' => 'weet u zeker dat u de volgende gebruiker wilt verwijderen: %s?',
	'UsersManager_ExceptionLoginExists' => 'Login \'%s\' bestaat reeds.',
	'UsersManager_ExceptionEmailExists' => 'Er is reeds een gebruiker met \'%s\' als email adres.',
	'UsersManager_ExceptionInvalidLogin' => 'Login mag enkel letters, nummers of de volgende karakters bevatten \'_\' or \'-\' or \'.\'',
	'UsersManager_ExceptionInvalidPassword' => 'Het password moet een lengte hebben tussen 6 en 26 karakters.',
	'UsersManager_ExceptionInvalidEmail' => 'Het email adres is ongeldig.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Gebruiker \'%s\' bestaat niet en kan dus niet verwijderd worden.',
	'UsersManager_ExceptionAdminAnonymous' => 'U kunt geen admin rechten toekennen aan de anonieme gebruiker.',
	'UsersManager_ExceptionEditAnonymous' => 'De anonieme gebruiker kan niet gewijzigd of verwijderd worden. Deze wordt door Piwik gebruikt om te bepalen of een gebruiker al dan niet is ingelogd. U kunt bijvoorbeeld uw statistieken publiekelijk maken door de anonieme gebruiker \'kijkers rechten\' te geven.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Gebruiker \'%s\' bestaat niet.',
	'UsersManager_ExceptionAccessValues' => 'De parameter toegang moet &eacute;&eacute;n van de volgede waarden bevatten : [ %s ]',
	'VisitFrequency_Evolution' => 'Recente ontwikkelingen',
	'VisitFrequency_ReturnVisits' => '%s terugkerende bezoekers',
	'VisitFrequency_ReturnActions' => '%s acties door de terugkerende bezoekers',
	'VisitFrequency_ReturnMaxActions' => '%s acties per terugkerende bezoeker (max.)',
	'VisitFrequency_ReturnTotalTime' => '%s totale browse tijd (terugkerende bezoekers)',
	'VisitFrequency_ReturnBounces' => '%s Bounces (1 page view / bezoek)',
	'VisitFrequency_WidgetOverview' => 'Frequentie overzicht',
	'VisitFrequency_WidgetGraphReturning' => 'Terugkerende bezoekers',
	'VisitFrequency_SubmenuFrequency' => 'Frequentie',
	'VisitorInterest_VisitsPerDuration' => 'Duur bezoek',
	'VisitorInterest_VisitsPerNbOfPages' => 'Pagina\'s per bezoek',
	'VisitorInterest_WidgetLengths' => 'Lengte bezoek',
	'VisitorInterest_WidgetPages' => 'Pagina\'s per bezoek',
	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frequentie &amp; Loyaliteit',
	'VisitorInterest_PlusXMin' => '%s min.',
	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min.',
	'VisitorInterest_OnePage' => '1 pagina',
	'VisitorInterest_NPages' => '%s pagina\'s',
	'VisitorInterest_BetweenXYSeconds' => '%1s-%2s sec.',
	'VisitsSummary_NbVisits' => '%s bezoeken',
	'VisitsSummary_NbUniqueVisitors' => '%s unieke bezoekers',
	'VisitsSummary_NbActions' => '%s acties',
	'VisitsSummary_TotalTime' => '%s totale duur',
	'VisitsSummary_MaxNbActions' => '%s acties per bezoek (max.)',
	'VisitsSummary_NbBounced' => '%s Bounces (1 page view / bezoek)',
	'VisitsSummary_Evolution' => 'Ontwikkeling van de laatste 30 %ss',
	'VisitsSummary_Report' => 'Totalen',
	'VisitsSummary_GenerateTime' => '%s seconden om deze pagina te genereren',
	'VisitsSummary_GenerateQueries' => '%s queries uitgevoerd',
	'VisitsSummary_WidgetLastVisits' => 'Recente bezoeken',
	'VisitsSummary_WidgetVisits' => 'Bezoeken totalen',
	'VisitsSummary_WidgetLastVisitors' => 'Recente unieke bezoekers',
	'VisitsSummary_WidgetOverviewGraph' => 'Totalen',
	'VisitsSummary_SubmenuOverview' => 'Totalen',
	'VisitTime_LocalTime' => 'Uur van de dag (tijdzone bezoeker)',
	'VisitTime_ServerTime' => 'Uur van de dag (tijdzone server)',
	'VisitTime_WidgetLocalTime' => 'Uur van de dag (tijdzone bezoeker)',
	'VisitTime_WidgetServerTime' => 'Uur van de dag (tijdzone server)',
	'VisitTime_SubmenuTimes' => 'Uur van de dag',
	'VisitTime_NHour' => '%s uur',
);
